==> haskell-hls-rename-plugin-1.0.2.0-171-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-rename-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-rename-plugin
version:              1.0.2.0
visibility:           public
id:                   hls-rename-plugin-1.0.2.0-48nLWPVo59G54SCOWcSeHM
key:                  hls-rename-plugin-1.0.2.0-48nLWPVo59G54SCOWcSeHM
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  39d695c88a8a2b98774dba0663accb4a
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-rename-plugin-1.0.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-rename-plugin-1.0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-1.0.2.0-48nLWPVo59G54SCOWcSeHM
depends:
    base-4.16.4.0 containers-0.6.5.1
    extra-1.7.14-G7RUcuOuw1aBbNpo23OJTR ghc-9.2.8
    ghc-exactprint-1.5.0-IoYMc2EGtXBy8XD1IgYUI
    ghcide-1.9.1.0-KC6zh4LlQMBDXwToCJ0uZw
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    hiedb-0.4.2.0-h4agzY0LS69StE4Fu3thc
    hls-plugin-api-1.6.0.0-2HKov0bcxf4CK3ldNr56xR
    hls-refactor-plugin-1.1.0.0-9wuFzrYaGsU52YwTMZLhIs
    lsp-1.6.0.0-5OWhLZsQFPYDtZtDz404eF
    lsp-types-1.6.0.0-Fj92Fy0soHoEAOIZ3C7KJM
    mod-0.2.0.1-16N6J7BAvpWIyjLk6grBkC
    syb-0.7.2.4-IT59ozboet0H3NdhoNJGts text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-rename-plugin-1.0.2.0-172-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-rename-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-rename-plugin
version:              1.0.2.0
visibility:           public
id:                   hls-rename-plugin-1.0.2.0-2MD8qYRJokUD83UR3G7i6
key:                  hls-rename-plugin-1.0.2.0-2MD8qYRJokUD83UR3G7i6
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  501df1407aa8e90999d87a02ff47a66b
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-rename-plugin-1.0.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-rename-plugin-1.0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-1.0.2.0-2MD8qYRJokUD83UR3G7i6
depends:
    base-4.16.4.0 containers-0.6.5.1
    extra-1.7.14-GJGjfBc9h4DFKhF9oMbXKG ghc-9.2.8
    ghc-exactprint-1.5.0-33lU3WOgSvWAfcvY8djhrj
    ghcide-1.9.1.0-2NBmNRkfWXM1NaaKimXpvI
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    hiedb-0.4.2.0-Hz7u5TLzZlg8ES5HSScY1U
    hls-plugin-api-1.6.0.0-IrWY97yx4Ki3UEHayHedNv
    hls-refactor-plugin-1.1.0.0-Hj2yYcKCFofDXiZHaeGrOi
    lsp-1.6.0.0-CM6WDlt9oDB5Oz9CDPKUO7
    lsp-types-1.6.0.0-A63ekFNN6F92bcaqnQodxb
    mod-0.2.0.1-wINVoxKuvH1VoSZHOnHXz
    syb-0.7.2.4-IT59ozboet0H3NdhoNJGts text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
